**********************
*PLEASE CITE PAPER AS:
*Zarach, Z.H., Parteka A. (2023). Export diversification and dependence on natural resources. Economic Modelling Volume 126, September 2023, 106436. https://doi.org/10.1016/j.econmod.2023.106436
***********************************************
*IF YOU USE REPLICATION PACKAGE, PLEASE CITE AS:
*Zarach, Z.H., & Parteka, A. (2023). Data accompanying the paper: Zarach and Parteka (2023), Export diversification and dependence on natural resources, Economic Modelling (Elsevier), 126 (2023) 106436. [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/844p-8614

***************************************
*THIS DO.FILE CREATES BASELINE DATABASE
***************************************

****************
*IMPORTANT NOTE!
****************
*Since source data used in this do.file may have been updated between today and the time when it was downloaded by authors, this baseline database might marginally vary from the one originally used by the authors, as far as data is concerned.
*Therefore, some differences in estimations results and summary statistics may occur, compared to results reported in abovementioned paper. 
*Versions of databases used by the authors (as well as the date of downloading them) are given below, next to every information regarding respective source data. 

/*_____________________________________________________________________________*/
/*First you have to create a following folder structure:

NR_DECOMPOSITION
	|_DATA
		|_SOURCE_DATA
	
All source files are to be stored in SOURCE DATA catalogue*/


//Setting a directory//
clear all
set more off
cd  "D:\NR_DECOMPOSITION\DATA"

*______________________________________________________________________________*
//PART 1: DATA ON COUNTRY SPECIFIC INDICATORS AND CLASSIFICATIONS//
********************************************************************************
//Step 1: including country-level data on GDP, population and employment from Penn World Table//
**Please download PWT database in Stata version from https://www.rug.nl/ggdc/productivity/pwt/?lang=en**
**To match all codes in do.files, please name your downloaded file as: pwt.dta and set it in SOURCE_DATA catalogue**
**Version downloaded by authors: PWT 10.0 (date: 01.2022)**
use "SOURCE_DATA\pwt.dta", clear
keep countrycode year rgdpe emp pop
keep if year>=1996 & year<=2018

*Replacing separate data for BEL and LUX with joint data for BELX (to match with country codes in our trade database)
replace countrycode="BELX" if countrycode=="BEL"
replace countrycode="BELX" if countrycode=="LUX"
collapse (sum) rgdpe emp pop, by (countrycode year)

*Labelling variables
la var rgdpe "Expenditure-side real GDP at chained PPPs (in mil. 2017US$)"
la var emp "Number of persons engaged (in millions)"
label variable pop "Population (in millions)"
la var countrycode "Exporter's country code; 3-letter country name abbreviation"
la var year "1996-2018"

*Renaming variables
rename countrycode Exporter

*Saving the database
save pwt_19962018.dta, replace  

********************************************************************************
//Step 2: including income classification based on historical records from World Bank (1996-2018)//
**Please download historical classification by income from https://datahelpdesk.worldbank.org/knowledgebase/articles/906519-world-bank-country-and-lending-groups**
**To match all codes in do.files, please name your downloaded file as: World Bank -  historical classification by income.xlsx and set it in SOURCE_DATA catalogue**
**Version downloaded by authors: 12.2021**
**H, M, LM, UM - high, middle, low-middle, upper-middle income**
**This classification is country and time(year) specific**

clear all
import excel "SOURCE_DATA\World Bank -  historical classification by income.xlsx", sheet("Country Analytical History") clear

*Removing unnecessary lines and variables
drop in 1/11
drop in 219/229

drop B C D E F G H I J K L M N O P Q R S T U V W X Y Z AA AB AC AD AE AF AG AI AJ AK AL AM AN AO AP AQ AR AS AT AU AV AW AX AY AZ BA BB BC BD BE BF BG BH BI BJ BK BL BM BN BO BP BQ
drop BR BS BT BU BV BW BX BY BZ CA CB CC CD CE CF CG CH CI CJ CK CL CM CN CO CP CQ CR CS CT CU CV CW CX CY CZ DA DB DC DD DE DF DG DH DI DJ DK DL DM DN DO DP DQ DR DS DT DU DV DW DX
drop DY DZ EA EB EC ED EE EF EG EH EI EJ EK EL EM EN EO EP EQ ER ES ET EU EV EW EX EY EZ FA FB FC FD FE FF FG FH FI FJ FK FL FM FN FO FP FQ FR FS FT FU FV FW FX FY FZ GA GB GC GD GE
drop GF GG GH GI GJ GK GL GM GN GO GP GQ GR GS GT GU GV GW GX GY GZ HA HB HC HD HE HF HG HH HI HJ HK HL HM HN HO HP HQ HR HS HT HU HV HW HX HY HZ IA IB IC ID IE IF IG IH II IJ IK IL IM IN IO IP IQ IR IS IT IU 

*Renaming remaining variables to match other source databases
rename A Exporter
rename AH CLS2018
la var Exporter "Exporter's country code; 3-letter country name abbreviation"
la var CLS2018 "Income classification, as of year 2018"

*Unifying classification for BEL and LUX (both high income - developed countries)
drop if Exporter=="LUX"
replace Exporter="BELX" if Exporter=="BEL"

*Saving the database
save income_classification.dta, replace

********************************************************************************
//Step 3: including data on quality of institutions// 
**Please download data on Control of Corruption, Government Effectiveness, Political Stability and Absence of Violence/Terrorism, Regulatory Quality, Rule of Law, Voice and Accountability (all in 'Percentile Rank' form) from Worldwide Governance Indicators (for all available countries and timespan of 1996-2018): https://databank.worldbank.org/source/worldwide-governance-indicators**
**To match all codes in do.files, please name your downloaded file as: quality of governance.xlsx and set it in SOURCE_DATA catalogue**
**Version downloaded by authors: 09.2022**

clear all
import excel "SOURCE_DATA\quality of governance.xlsx", sheet("Data") firstrow 

*Removing unnecessary lines and variables; renaming variables to match other source databases
drop in 1285/1289
drop SeriesCode CountryName
rename CountryCode Exporter
rename SeriesName index

*Replacing missing data and destringing variables
foreach var in YR1996 YR1998 YR2000 YR2002 YR2003 YR2004 YR2005 YR2006 YR2007 YR2008 YR2009 YR2010 YR2011 YR2012 YR2013 YR2014 YR2015 YR2016 YR2017 YR2018 {
replace `var'="." if `var'==".."
destring `var', replace
}

*Reshaping the database from wide to long format
reshape long YR, j(year) i(index Exporter) s
destring year, replace

*Destringing variables into float format 
encode index, generate(ind_des)
order ind_des, first
drop index

*Reshaping the database from long to wide format
reshape wide YR, j(ind_des) i(Exporter year)

*Renaming variables 
rename YR1 VAR1
rename YR2 VAR2
rename YR3 VAR3
rename YR4 VAR4
rename YR5 VAR5
rename YR6 VAR6

*Replacing separate data for BEL and LUX with joint data for BELX (to match with country codes in our trade database) 
replace Exporter="BELX" if Exporter=="BEL" | Exporter=="LUX"
collapse (mean) VAR1 VAR2 VAR3 VAR4 VAR5 VAR6, by (Exporter year)

*Labeling variables
la var VAR1 "Control of Corruption: Percentile Rank"
la var VAR2 "Government Effectiveness: Percentile Rank"
la var VAR3 "Political Stability and Absence of Violence/Terrorism: Percentile Rank"
la var VAR4 "Regulatory Quality: Percentile Rank"
la var VAR5 "Rule of Law: Percentile Rank"
la var VAR6 "Voice and Accountability: Percentile Rank"
la var Exporter "Exporter's country code; 3-letter country name abbreviation"
la var year "1996-2018"

*Generating joint 'quality of institutions' index as an average of all six indices
egen INST = rowmean(VAR1 VAR2 VAR3 VAR4 VAR5 VAR6)
la var INST "Quality of institutions; mean of VAR1-VAR6; percentile rank"

*Saving the database
save institutions.dta, replace

********************************************************************************
//Step 4: including data on commodities' prices// 
**Annual price indices of selected natural resources from the World Bank Commodity Price Data Annual Indices**
**Data used in estimations as a substitution for time fixed effects**
**More information regarding origin of price indices to be found in "Legend" tab of this source file (commodity_prices.xlsx)**
**File commodity_prices.xlsx included in the replication package; please set it in your SOURCE_DATA catalogue**

clear all
import excel "SOURCE_DATA\commodity_prices_v1.xlsx", sheet("Data") firstrow

*Labeling variables
la var priceRC1 "All natural resources' price index"
la var priceRC2 "Forestry resources' price index" 
la var priceRC3 "Fuel resources' price index" 
la var priceRC4 "Metal resources' price index" 
la var priceRC5 "Mineral resources' price index" 

*Saving the database
save commodity_prices.dta, replace

*______________________________________________________________________________*
//PART 2: TRADE DATA AND TRADE PRODUCTS' CLASSIFICATIONS//
********************************************************************************
//Step 1: Country codes//
**This file associates the ISO 3-digit numeric codes used in BACI databases with country full names and 3-letter country name abbreviation used in other source databases**
**This file accompanies core BACI trade data files**
**File country_codes_V202102.csv included in the replication package; please set it in your SOURCE DATA catalogue**

clear all
import delimited "SOURCE_DATA\country_codes_V202102_v1.csv", clear

*Removing unnecessary variables
drop iso_2digit_alpha country_name_full

*Renaming variables to match other source databases
rename country_name_abbreviation CountryName
rename iso_3digit_alpha CountryCode
rename country_code Exporter

*Ordering and renaming variables
gen Importer = Exporter
order CountryCode CountryName Exporter Importer

la var CountryCode "3-letter country name abbreviation"
la var CountryName "Country full name"

*Saving the database
save country_codes.dta, replace

********************************************************************************
//Step 2: Trade products' classifications//
**Product-level (HS 6 digit) taxonomies: for natural resources and technologically advanced products**
**RC -> abbreviation for Resource Classification**
**More information regarding used classifications to be found in "Legend" tab of this source file (classifications.xlsx)**
**File classifications.xlsx included in the replication package; please set it in your SOURCE_DATA catalogue**

clear all
******************
*NATURAL RESOURCES
******************
import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("RC1") firstrow clear
la var RC1 "=1 if products belong to all 4 resource groups: metal, fuel, mineral, forest"
save RC1.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("RC2") firstrow clear
la var RC2 "=1 if products belong to FORESTRY group"
save RC2.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("RC3") firstrow clear
la var RC3 "=1 if products belong to FUEL group"
save RC3.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("RC4") firstrow clear
la var RC4 "=1 if products belong to METAL group"
save RC4.dta, replace

import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("RC5") firstrow clear
la var RC5 "=1 if products belong to MINERAL group"
save RC5.dta, replace

**********************************
*TECHNOLOGICALLY ADVANCED PRODUCTS
**********************************
import excel "SOURCE_DATA\classifications_v1.xlsx", sheet("TECH") firstrow clear
la var TECH "=1 if products belong to TECH group"
save TECH.dta, replace

**************
*PRODUCT CODES
**************
**This file associates the HS 6-digit product codes to product names and accompanies core BACI trade data files**
**File product_codes_HS96_V202102.csv included in the replication package; please set it in your SOURCE_DATA catalogue**

clear all
import delimited "SOURCE_DATA\product_codes_HS96_V202102_v1.csv", varnames(1) clear

*Cleaning data and prepering for the merge
drop if code=="9999AA"
destring code, generate (ProductCode)
drop code
rename description ProductDescription
order ProductCode ProductDescription

*Labelling variables
la var ProductCode "6-digit product codes in compliance with HS96 nomenclature"
la var ProductDescription "Product names in compliance with HS96 nomenclature"

*Merging all classification files
foreach k in RC1 RC2 RC3 RC4 RC5 TECH{
merge m:m ProductCode using "`k'.dta", force
replace `k'=0 if `k'==.
drop if _merge==2
drop _merge
erase `k'.dta
}

*Saving the database
save product_codes.dta, replace

********************************************************************************
//Step 3: Product-level bilateral trade flows//
**Please download an archival version of BACI CEPII HS96 database (i.e. 202102 version) from http://www.cepii.fr/CEPII/en/bdd_modele/bdd_modele_item.asp?id=37 (to be found in tab ARCHIVES)**
**Please create a separate folder within SOURCE_DATA catalogue and name it BACI_HS96_V202102; then put all source trade data files downloaded from CEPII's BACI repository in this folder**
**BACI CEPII provides yearly product-level data on bilateral trade flows; only the strictly positive trade flows are recorded; trade flows below 1000 USD value do not appear; BACI databases are free from UN Special Codes**

/*letters used as variable names stand for:
t -> Year during which the recorded trade flows took place
i -> Exporter (ISO 3-digit country code)
j -> Importer (ISO 3-digit country code)
v -> Value of the trade flow (in thousands current USD)
k -> Product category (HS 6-digit code)
q -> Quantity (in metric tons)
*/

clear all
set more off
forvalues i = 1996/2018 {
import delimited "SOURCE_DATA\BACI_HS96_V202102\BACI_HS96_Y`i'_V202102.csv", clear
save "SOURCE_DATA\BACI_HS96_V202102\BACI_HS96_Y`i'_V202102.dta", replace
}
**********************
*Initial data cleaning
********************** 
forvalues i = 1996/2018 {
use "SOURCE_DATA\BACI_HS96_V202102\BACI_HS96_Y`i'_V202102.dta", clear

*Dropping Custom Unions, Trade Unions and countries which don't exist in 1996-2018 timespan: 230"Former Ethiopia" 278"NRD" 280"RFN" 490"Other Asia, not elsewhere specified" 697"Europe EFTA, not elsewhere specified" 711"Southern African Customs Union" 810"Former USSR Soviet Union" 849"US Miscellaneous Pacific Islands"
foreach n in 230 278 280 490 697 711 810 849{
drop if i == `n'
drop if j == `n'
}

*Deleting unnecessary variables and renaming remaining ones 
drop q
rename i Exporter
rename j Importer
rename v Value
rename k ProductCode
rename t year

*Changing country numbers for 3-letter country codes; both for Exporter and Importer
foreach z in Exporter Importer{
merge m:m `z' using "country_codes.dta", force
drop if _merge==2
drop _merge 
drop `z' 
rename CountryCode `z'
}

*Labeling variables
la var Importer "Importer (3-letter country code)"
la var Exporter "Exporter (3-letter country code)"
la var Value "Value of the trade flow (in thousands current USD)"
la var ProductCode "Product category (HS 6-digit code)"
la var year "1996-2018"

**********************
*Further data cleaning
**********************
*Deleting UN Special Codes (other than 9999AA, which is not included in BACI databases)
foreach n in 151930 271011 271012 271013 271014 271015 271016 271019 271021 271022 271025 271026 271027 271029 271091 271093 271094 271095 271096 271099 380999 5127 5131{
drop if ProductCode ==	`n'
}
*Deleting product codes which vanish throughout the 1996-2018 timespan (i.e. product codes no longer used in HS96 nomenclature in further years or not changed into new product code with conversion tables; step taken to obtain a balanced dataset)
foreach n in 10120 20820 50300 71110 81220 110312 110314 110411 110421 120792 120919 120926 121110 121230 130110 130214 140210 140310 140390 150510 151540 151560 200120 230670 230810 250621 251621 252700 253040 262050 270760 280522 281123 281620{
drop if ProductCode == `n'
}
foreach n in 282733 282734 282736 282738 283020 283030 283323 283422 283523 283670 283800 284110 284140 290316 290343 290344 290515 290614 290714 290730 290820 290942 291213 291230 291523 291534 291535 291635 291731 291817 292112 292222 293010 293221 293610 293729 293921 293970 310270 310320 310410 320630 320643 330121 330122 330126 370251 370291{
drop if ProductCode == `n'
}
foreach n in 370292 381720 392041 410122 410129 410140 410310 410410 410421 410511 410512 410611 410612 410721 420610 430120 430140 430150 430170 430212 430213 441111 441191 441222 460110 480521 480522 480523 480710 481012 481410 482351 482359 500310 520853 521012 521022 521042 521052 521121{
drop if ProductCode == `n'
}
foreach n in 521122 530410 530490 530511 530519 530521 530529 530591 530830 540320 551322 551342 551413 551432 551592 560730 570251 570252 580124 580134 590491 600241 610110 610321 610411 610421 611410 620321 630641 640191 640330 650692 660310 681210 681220 681230 681240 701091 701093 701094 722520 722693{
drop if ProductCode == `n'
}
foreach n in 722694 722910 730220 731413 740120 740323 740722 741420 741531 741600 780300 780500 800600 810192 811230 811240 841822 842850 843062 844210 844220 844841 845691 846110 846911 846912 846930 847040 850890 852431 854050 854072 854214 854219 854311 860620 880110 901041 903130 910112 910620 910891 911210 920410 920920 930521 961330 710820 711890 999999{
drop if ProductCode == `n'
}
foreach n in 701200 842520 852010 911420 441139{
drop if ProductCode == `n'
}
***********************************************************************************************************************************************************************************
*Following two steps taken in order to maintain the same set of countries ("WORLD") for which trade and output per worker (GDP/emp) data is available throughout the whole timespan
***********************************************************************************************************************************************************************************
*Deleting countries with incomplete data (countries not providing data for every year throughout 1996-2018 and countries which gained independence during 1996-2018 timespan e.g. Serbia (SRB))
foreach country in "ASM" "BWA" "GUM" "LSO" "MYT" "NAM" "PSE" "SMR" "SWZ" "ZAF" "CUW" "BES" "SXM" "ANT" "SSD" "BLM" "SCG" "MNE" "SRB"{
drop if Exporter == "`country'"
drop if Importer == "`country'"
}
*Deleting countries with population<100k and countries for which there is no GDP and employment data in PWT10.0
foreach country in "ABW" "AFG" "AIA" "AND" "ATF" "ATG" "BMU" "CCK" "COK" "CUB" "CXR" "CYM" "DMA" "FLK" "FSM" "GIB" "GRL" "IOT" "KIR" "KNA" "LBY" "MHL" "MNP" "MSR" "NCL" "NFK" "NIU" "NRU" "PCN" "PLW" "PNG" "PRK" "PYF" "SHN" "SLB" "SOM" "SPM" "SYC" "TCA" "TKL" "TLS" "TON" "TUV" "VGB" "VUT" "WLF" "WSM"{
drop if Exporter == "`country'"
drop if Importer == "`country'"
}

*Preparing joint data for Belgium (BEL) and Luxemburg (LUX) (under the abbreviation BELX) to match the trend from year 1996, 1997 and 1998 where data for BEL and LUX appear as a sum under the abbreviation BEL
replace Exporter="BELX" if Exporter=="BEL" | Exporter=="LUX"
replace Importer="BELX" if Importer=="BEL" | Importer=="LUX"
replace CountryName="Belgium and Luxembourg" if Exporter=="BELX"
collapse (sum) Value , by (Exporter ProductCode Importer CountryName year)
la var Value "Export value (in thousands current USD)"


************************************************
*Change from bilateral into unilateral dimension 
************************************************
*Deleting Importer variable
collapse (sum) Value, by (Exporter ProductCode CountryName year)
la var Value "Export value (in thousands current USD)"

*Adding product classifications
merge m:m ProductCode using "product_codes.dta"
drop if _merge==2
drop _merge

save trade-data-`i'.dta, replace
}
********************************************************************************
//Step 4: Country-level indicators based on trade data//
**Calculating export shares for natural resources and technological products**
clear all
set more off
forvalues i = 1996/2018 {

use trade-data-`i'.dta, clear

/*Before following calculations, xfill command needs to be downloaded and installed. To obtain xfill please type the following into Stata:
net from https://www.sealedenvelope.com/
and follow the instructions on screen*/

*Rectangulizing the dataset (in order to obtain a full matrix of products for all countries (even if actual export value is missing))
fillin ProductCode Exporter
drop _fillin
egen CountryNumber=group(Exporter)
order CountryNumber, before(ProductCode)
replace year=`i' if year==.

foreach z in CountryName Exporter{
xfill `z', i(CountryNumber)
}
************************************************************
*Calculating total exports and export shares -> all products 
************************************************************
*Countries' total exports
egen Ec = total(Value), by (Exporter)
la var Ec "Country total exports"
*Worlds' total exports
egen Ew = total(Value)
la var Ew "Worlds' total exports"
*Share of countries' export in world's exports
gen Scw = Ec/Ew
la var Scw "Share of countries' total exports in world's total exports"
*Countries' product 'i' total exports
gen Eci = Value
la var Eci "Country total product 'i' exports"
*Worlds' product 'i' total exports
egen Ewi = total(Value), by (ProductCode)
la var Ewi "Worlds' total product 'i' exports"
*Share of countries' export in world's exports (by product)
gen Sci = Eci/Ec
la var Sci "Share of product's exports in country total exports"
gen Swi = Ewi/Ew
la var Swi "Share of product's exports in worlds' total exports"
*Revealed Comparative Advantage (RCA) calculated for every product
gen RCA = Sci/Swi
la var RCA "RCA index, by product, w.r.t. world export of product 'i'"

******************************************************************
*Calculating total exports and export shares -> product groups 'k'
******************************************************************
foreach k in RC1 RC2 RC3 RC4 RC5 TECH{
*Countries' total exports (by product groups)
egen Ec`k' = total(Value) if `k'==1,   by (Exporter)
xfill Ec`k', i(CountryNumber)
la var Ec`k' "Country total exports (`k' group)"

*Worlds' total exports (by product groups)
egen Ew`k' = total(Value) if `k'==1
xfill Ew`k', i(CountryNumber)
la var Ew`k' "Worlds' total exports (`k' group)"

*Share of group's exports in countries'(world's) total exports 
gen Sc`k' = Ec`k'/Ec
la var Sc`k' "Share of group `k' in country total exports"
gen Sw`k' = Ew`k'/Ew
la var Sw`k' "Share of group `k' in world's total exports"

*Share of countries' export in world's exports (by product groups)
gen Scw`k' = Ec`k'/Ew`k'
xfill Scw`k', i(CountryNumber)
la var Scw`k' "Share of countries' exports in world's exports (group `k')"
}
********************************************************************************************************************************************************
*Calculating total exports and export shares -> resource(r) and non-resource(nr) products as well as technological(t) and non-technological(nt) products
********************************************************************************************************************************************************
//Calculations by product group (classification) `k' and by product `i'//

/////////////////////
//NATUTAL RESOURCES//
/////////////////////
foreach k in RC1 RC2 RC3 RC4 RC5{

*Countries' total resource and non-resource exports 
egen Ec`k'_r = total(Value) if `k'==1,   by (Exporter)
xfill Ec`k'_r, i(CountryNumber)
la var Ec`k'_r "Country total resource exports (`k' group)"
egen Ec`k'_nr = total(Value) if  `k'==0,   by (Exporter)
xfill Ec`k'_nr, i(CountryNumber)
la var Ec`k'_nr "Country total non-resource exports (`k' group)"

*Worlds' total resource and non-resource exports
egen Ew`k'_r = total(Value) if `k'==1
xfill Ew`k'_r, i(CountryNumber)
la var Ew`k'_r "Worlds' total resource exports (`k' group)"
egen Ew`k'_nr = total(Value) if `k'==0
xfill Ew`k'_nr, i(CountryNumber)
la var Ew`k'_nr "Worlds' total non-resource exports (`k' group)"

*Countries' resource and non-resource exports (by product)
egen Ec`k'_ir = total(Value) if `k'==1,   by (Exporter ProductCode)
la var Ec`k'_ir "Country total resource exports (by product, `k' group)"
egen Ec`k'_inr = total(Value) if `k'==0,   by (Exporter ProductCode)
la var Ec`k'_inr "Country total non-resource exports (by product, `k' group)"

*Worlds' resource and non-resource exports (by product)
egen Ew`k'_ir = total(Value) if `k'==1, by (ProductCode)
la var Ew`k'_ir "Worlds' total resource exports (by product, `k' group)"
egen Ew`k'_inr = total(Value) if `k'==0, by (ProductCode)
la var Ew`k'_inr "Worlds' total non-resource exports (by product, `k' group)"

*Share of resource/non-resource exports in countries'(world's) total exports 
gen Sc`k'_r = Ec`k'_r/Ec
la var Sc`k'_r "Share of resource exports in country total exports (`k' group)"
gen Sw`k'_r = Ew`k'_r/Ew
la var Sw`k'_r "Share of resource exports in worlds' total exports (`k' group)"
gen Sc`k'_nr = Ec`k'_nr/Ec
la var Sc`k'_nr "Share of non-resource exports in country total exports (`k' group)"
gen Sw`k'_nr = Ew`k'_nr/Ew
la var Sw`k'_nr "Share of non-resource exports in worlds' total exports (`k' group)"

*Share of product's exports in countries'(world's) resource/non-resource exports
gen Sc`k'_ir = Ec`k'_ir/Ec`k'_r
la var Sc`k'_ir "Share of product's exports in country total resource exports (`k' group)"
gen Sw`k'_ir = Ew`k'_ir/Ew`k'_r
la var Sw`k'_ir "Share of product's exports in worlds' total resource exports (`k' group)"
gen Sc`k'_inr = Ec`k'_inr/Ec`k'_nr
la var Sc`k'_inr "Share of product's exports in country total non-resource exports (`k' group)"
gen Sw`k'_inr = Ew`k'_inr/Ew`k'_nr
la var Sw`k'_inr "Share of product's exports in worlds' total non-resource exports (`k' group)"

*Share of countries' resource exports in world's exports (by product groups)
gen Scw`k'_r = Ec`k'_r/Ew`k'_r
xfill Scw`k'_r, i(CountryNumber)
la var Scw`k'_r "Share of countries' resource exports in worlds' resource exports (`k' group)"

*Revealed Comparative Advantage (RCA) calculated for product groups
gen RCA`k' = Sc`k'/Sw`k'
la var RCA`k' "RCA index, by group, w.r.t. world export of group `k'"

*Number of resource products in which country is specialising (w.r.t. world)
gen B = 1 if RCA>1 & RCA!=. & `k'==1
egen RCAspecres`k' = total(B),   by (Exporter)
la var RCAspecres`k' "Number of products with RCA>1, within group `k'"
drop B
}
/////////////////////////////////////
//TECHNOLOGICALLY ADVANCED PRODUCTS//
/////////////////////////////////////
*Countries' total technological and non-technological exports 
egen EcTECH_t = total(Value) if TECH==1,   by (Exporter)
xfill EcTECH_t, i(CountryNumber)
la var EcTECH_t "Country total tech exports (TECH group)"
egen EcTECH_nt = total(Value) if  TECH==0,   by (Exporter)
xfill EcTECH_nt, i(CountryNumber)
la var EcTECH_nt "Country total non-tech exports (TECH group)"

*Worlds' total technological and non-technological exports
egen EwTECH_t = total(Value) if TECH==1
xfill EwTECH_t, i(CountryNumber)
la var EwTECH_t "Worlds' total tech exports (TECH group)"
egen EwTECH_nt = total(Value) if TECH==0
xfill EwTECH_nt, i(CountryNumber)
la var EwTECH_nt "Worlds' total non-tech exports (TECH group)"

*Countries' technological and non-technological exports (by product)
egen EcTECH_it = total(Value) if TECH==1,   by (Exporter ProductCode)
la var EcTECH_it "Country total tech exports (by product, TECH group)"
egen EcTECH_int = total(Value) if TECH==0,   by (Exporter ProductCode)
la var EcTECH_int "Country total non-tech exports (by product, TECH group)"

*Worlds' technological and non-technological exports (by product)
egen EwTECH_it = total(Value) if TECH==1, by (ProductCode)
la var EwTECH_it "Worlds' total tech exports (by product, TECH group)"
egen EwTECH_int = total(Value) if TECH==0, by (ProductCode)
la var EwTECH_int "Worlds' total non-tech exports (by product, TECH group)"

*Share of technological/non-technological exports in countries'(world's) total exports 
gen ScTECH_t = EcTECH_t/Ec
la var ScTECH_t "Share of tech exports in country total exports (TECH group)"
gen SwTECH_t = EwTECH_t/Ew
la var SwTECH_t "Share of tech exports in worlds' total exports (TECH group)"
gen ScTECH_nt = EcTECH_nt/Ec
la var ScTECH_nt "Share of non-tech exports in country total exports (TECH group)"
gen SwTECH_nt = EwTECH_nt/Ew
la var SwTECH_nt "Share of non-tech exports in worlds' total exports (TECH group)"

*Share of product's exports in countries'(world's) technological/non-technological exports
gen ScTECH_it = EcTECH_it/EcTECH_t
la var ScTECH_it "Share of product's exports in country total tech exports (TECH group)"
gen SwTECH_it = EwTECH_it/EwTECH_t
la var SwTECH_it "Share of product's exports in worlds' total tech exports (TECH group)"
gen ScTECH_int = EcTECH_int/EcTECH_nt
la var ScTECH_int "Share of product's exports in country total non-tech exports (TECH group)"
gen SwTECH_int = EwTECH_int/EwTECH_nt
la var SwTECH_int "Share of product's exports in worlds' total non-tech exports (TECH group)"

*Share of countries' technological exports in world's exports (by product groups)
gen ScwTECH_t = EcTECH_t/EwTECH_t
xfill ScwTECH_t, i(CountryNumber)
la var ScwTECH_t "Share of countries' resource exports in worlds' tech exports (TECH group)"


****************************************************************************************
//Step 5: Decomposition of relative Theil index//
**Decomposition into within (resource(r) and non-resource(nr)) and between components**
** Calculations for all natural resources' classifications**

foreach k in RC1 RC2 RC3 RC4 RC5{

*Logarithm of division between countries' and world's share of resource/non-resource exports in total exports 
gen ln_S`k'nr = ln(Sc`k'_nr/Sw`k'_nr)
gen ln_S`k'r = ln(Sc`k'_r/Sw`k'_r)

*Logarithm of division between share of product i's exports in countries'and world's resource/non-resource exports
gen ln_S`k'inr = ln(Sc`k'_inr/Sw`k'_inr)
gen ln_S`k'ir = ln(Sc`k'_ir/Sw`k'_ir)

*Weighted Theil index calculated for resource and non-resource group //formula no.2 from Gnidchenko (2021)//
egen RT_inr_`k' = total(Sc`k'_inr*ln_S`k'inr), by (Exporter)
egen RT_ir_`k' = total(Sc`k'_ir*ln_S`k'ir), by (Exporter)

*Resource part of component between
gen w = Sc`k'_r*ln_S`k'r
*Non-resource part of component between
gen y = Sc`k'_nr*ln_S`k'nr
*Between component
egen between`k' = rowtotal(w y) 

*Within resource component
gen within`k'_r = Sc`k'_r*RT_ir_`k'
*Within non-resource component
gen within`k'_nr = Sc`k'_nr*RT_inr_`k'

*Weighted Theil index calculated for every country //formula no.5 from Gnidchenko (2021)//
egen RTc_`k' = rowtotal (between`k' within`k'_r within`k'_nr)
drop w y 

*Labelling variables
la var within`k'_r "Within resource component of relative Theil index; class. `k'"
la var within`k'_nr "Within non-resource component of relative Theil index; class. `k'"
la var between`k' "Between component of relative Theil index; class. `k'"
la var RTc_`k' "Relative (weighted) Theil index; classification `k'"
la var RT_inr_`k' "Weighted Theil index of non-resource group; classification `k'"
la var RT_ir_`k' "Weighted Theil index of resource group; classification `k'"
}

*********************************************************************************************************************
*Calculating weighted Theil index for technological and non-technological part of export basket (classification TECH)
*********************************************************************************************************************

*Logarithm of division between countries' and world's share of tech/non-tech exports in total exports 
gen ln_STECHnt = ln(ScTECH_nt/SwTECH_nt)
gen ln_STECHt = ln(ScTECH_t/SwTECH_t)

*Logarithm of division between share of product i's exports in countries'and world's tech/non-tech exports
gen ln_STECHint = ln(ScTECH_int/SwTECH_int)
gen ln_STECHit = ln(ScTECH_it/SwTECH_it)

*Weighted Theil index calculated for technological and non-technological group //formula no.2 from Gnidchenko (2021)//
egen RT_int_TECH = total(ScTECH_int*ln_STECHint), by (Exporter)
egen RT_it_TECH = total(ScTECH_it*ln_STECHit), by (Exporter)

la var RT_int_TECH "Weighted Theil index of non-tech group; classification TECH"
la var RT_it_TECH "Weighted Theil index of tech group; classification TECH"

save country-level-indicators-`i'.dta, replace 
}

*______________________________________________________________________________*
//PART 3: MERGING ALL SOURCE DATABASES//
*************************************************************************************************************
//Step 1: Database with weighted Theil and its components (all natural resources' and TECH classifications)//
**file name: WEIGHTED-THEIL.dta**
clear all
forvalues i = 1996/2018{

*Collapsing variables regarding weighted Theil index
foreach k in RC1 RC2 RC3 RC4 RC5{
use country-level-indicators-`i'.dta, clear
collapse between`k' within`k'_r within`k'_nr RTc_`k' RT_ir_`k' RT_inr_`k' RT_int_TECH RT_it_TECH, by (Exporter CountryName)
save RT-`k'`i'.dta, replace
}
*In this step, files for classification RC5 are stored in memory - attaching files for classifications RC1-RC4
foreach k in RC1 RC2 RC3 RC4{
merge 1:1 Exporter using "RT-`k'`i'.dta"
drop _merge
}
*Adding variable 'year' to the database
gen year=`i'
save RT-`i'.dta, replace
}
*Appending databases for all years
use RT-2018.dta, clear
forvalues i = 1996/2017 {
append using "RT-`i'.dta"
}
*Labelling variables
foreach k in RC1 RC2 RC3 RC4 RC5{
la var between`k' "Between component of relative Theil index; class. `k'"
la var within`k'_r "Within resource component of relative Theil index; class. `k'"
la var within`k'_nr "Within non-resource component of relative Theil index; class. `k'"
la var RTc_`k' "Relative (weighted) Theil index; classification `k'"
la var RT_ir_`k' "Weighted Theil index of resource group; classification `k'"
la var RT_inr_`k' "Weighted Theil index of non-resource group; classification `k'"
}
la var RT_int_TECH "Weighted Theil index of non-tech group; classification TECH"
la var RT_it_TECH "Weighted Theil index of tech group; classification TECH"

*Ordering and sorting variables 
order Exporter CountryName year, before(betweenRC1)
order betweenRC5 withinRC5_r withinRC5_nr RTc_RC5 RT_ir_RC5 RT_inr_RC5 RT_int_TECH RT_it_TECH, after(RT_inr_RC4)
sort Exporter year

*Saving the database
save WEIGHTED-THEIL.dta, replace

**************************************************************************************************************************
//Step 2: Database with country-level indicators (export shares, total values of exports, export specialisation indices)//
**file name: COUNTRY-LEVEL-INDICATORS.dta**
forvalues i = 1996/2018{

*Collapsing variables regarding country-level indicators
foreach k in RC1 RC2 RC3 RC4 RC5{
use country-level-indicators-`i'.dta, clear
collapse Ec Ew Ec`k'_r Ew`k'_r Sc`k'_r Sc`k'_nr Scw`k' RCA RCA`k' RCAspecres`k' EcTECH_t ScTECH_t, by (Exporter CountryName)
save `k'`i'.dta, replace
}

*In this step, files for classification RC5 are stored in memory - attaching files for classifications RC1-RC4
foreach k in RC1 RC2 RC3 RC4{
merge 1:1 Exporter using "`k'`i'.dta"
drop _merge
}
*Adding variable 'year' to the database
gen year=`i'
save country-level-`i'.dta, replace
}
*Appending databases for all years
use country-level-2018.dta, clear
forvalues i = 1996/2017{
append using "country-level-`i'.dta"
}
*Labelling variables
foreach k in RC1 RC2 RC3 RC4 RC5{
la var Ec`k'_r "Country total resource exports (`k' group)"
la var Ew`k'_r "Worlds' total resource exports (`k' group)"
la var Sc`k'_r "Share of resource exports in country total exports (`k' group)"
la var Sc`k'_nr "Share of non-resource exports in country total exports (`k' group)"
la var Scw`k' "Share of countries' exports in world's exports (group `k')"
la var RCA`k' "RCA index, by group, w.r.t. world export of group `k'"
la var RCAspecres`k' "Number of products with RCA>1, within group `k'"
}
la var Ec "Country total exports"
la var Ew "Worlds' total exports"
la var RCA "RCA index, by product, w.r.t. world export of product 'i'"
la var EcTECH_t "Country total tech exports (TECH group)"
la var ScTECH_t "Share of tech exports in country total exports (TECH group)"

*Ordering and sorting variables 
order Exporter CountryName year Ec Ew RCA, before(EcRC1_r)
order EcRC5_r EwRC5_r ScRC5_r ScRC5_nr ScwRC5 RCARC5 RCAspecresRC5 EcTECH_t ScTECH_t, after(RCAspecresRC4)
sort Exporter year

*Saving the database
save COUNTRY-LEVEL-INDICATORS.dta, replace

************************************************************************************
//Step 3: Merging trade databases with previously prepared country-level databases//
use COUNTRY-LEVEL-INDICATORS.dta, clear

merge m:m Exporter year using "WEIGHTED-THEIL.dta"
drop if _merge==2
drop _merge

merge m:m Exporter year using "pwt_19962018.dta" 
drop if _merge==2
drop _merge

merge m:m Exporter using "income_classification.dta"
drop if _merge==2
drop _merge
order CLS2018, before (Ec)

merge m:m Exporter year using "institutions.dta"
drop if _merge==2
drop _merge

merge m:m year using "commodity_prices.dta"
drop if _merge==2
drop _merge
sort Exporter year
la var year "1996-2018"

*Saving the baseline database
save EconomicModelling_ZarachParteka_BaselineData.dta, replace

*Deleting all unnecessary preliminary databases used beforehand to built baseline database
forvalues i = 1996/2018{
erase trade-data-`i'.dta
erase country-level-`i'.dta
erase RT-`i'.dta

foreach k in RC1 RC2 RC3 RC4 RC5{
erase RT-`k'`i'.dta
erase `k'`i'.dta
}
}
