**********************
*PLEASE CITE PAPER AS:
*Zarach, Z.H., Parteka A. (2023). Export diversification and dependence on natural resources. Economic Modelling Volume 126, September 2023, 106436. https://doi.org/10.1016/j.econmod.2023.106436
***********************************************
*IF YOU USE REPLICATION PACKAGE, PLEASE CITE AS:
*Zarach, Z.H., & Parteka, A. (2023). Data accompanying the paper: Zarach and Parteka (2023), Export diversification and dependence on natural resources, Economic Modelling (Elsevier), 126 (2023) 106436. [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/844p-8614

**********************************************************
*THIS DO.FILE CALCULATES ECONOMETRIC MODELS - MAIN RESULTS
**********************************************************
clear all
set more off
cd "D:\NR_DECOMPOSITION"
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 
xtset countryid year

//Table 5 (eq.4 and eq.5)//
**Exploring the relationship between overall natural resource dependence and diversification of overall, non-resource and technologically advanced exports**
xi: ivreg2 ln_RT ScRC1_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons  excel replace 
xi: ivreg2 ln_RT ScRC1_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 ln_RT ScRC1_r INST_ip interaction_INST_RC1 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen

foreach z in ln_RT_inr_RC1 ln_RT_it_TECH{
xi: ivreg2 `z' ScRC1_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC1_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC1_r INST_ip interaction_INST_RC1 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

//Table 6 (eq.5)//
**Exploring the relationship between natural resource dependence (all types of resources) and diversification of non-resource exports**
xi: ivreg2 ln_RT_inr_RC1 ln_SIZE INST_ip ScRC1_r interaction_INST_RC1 (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel replace

foreach k in RC2 RC3 RC4 RC5{
xi: ivreg2 ln_RT_inr_`k' ln_SIZE INST_ip Sc`k'_r interaction_INST_`k' (l.ln_DEV=l2.ln_DEV) price`k', gmm2s robust
quietly outreg2 using "TABLE6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

//Table 7 (eq.5)//
**Exploring the relationship between natural resource dependence (all types of resources) and diversification of technologically advanced exports**
xi: ivreg2 ln_RT_it_TECH ln_SIZE INST_ip ScRC1_r interaction_INST_RC1 (l.ln_DEV=l2.ln_DEV) priceRC1, gmm2s robust
quietly outreg2 using "TABLE7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel replace

foreach k in RC2 RC3 RC4 RC5{
xi: ivreg2 ln_RT_it_TECH ln_SIZE INST_ip Sc`k'_r interaction_INST_`k' (l.ln_DEV=l2.ln_DEV) price`k', gmm2s robust
quietly outreg2 using "TABLE7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}




