**********************
*PLEASE CITE PAPER AS:
*Zarach, Z.H., Parteka A. (2023). Export diversification and dependence on natural resources. Economic Modelling Volume 126, September 2023, 106436. https://doi.org/10.1016/j.econmod.2023.106436
***********************************************
*IF YOU USE REPLICATION PACKAGE, PLEASE CITE AS:
*Zarach, Z.H., & Parteka, A. (2023). Data accompanying the paper: Zarach and Parteka (2023), Export diversification and dependence on natural resources, Economic Modelling (Elsevier), 126 (2023) 106436. [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/844p-8614

**************************************************************************************
*THIS DO.FILE CALCULATES ECONOMETRIC MODELS - EXTENSIONS AND ROBUSTNESS CHECKS RESULTS
**************************************************************************************
clear all
set more off
cd "D:\NR_DECOMPOSITION"
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 
xtset countryid year

//Table B.3//
xi: reg ln_RT ScRC3_r ln_SIZE priceRC3 if CLS2018=="H", robust
quietly outreg2 using "TABLE_B3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons  excel replace 

foreach z in M L{
xi: reg ln_RT ScRC3_r ln_SIZE priceRC3 if CLS2018=="`z'", robust
quietly outreg2 using "TABLE_B3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

foreach z in H M L{
xi: reg ln_RT_inr_RC3 ScRC3_r ln_SIZE priceRC3 if CLS2018=="`z'", robust
quietly outreg2 using "TABLE_B3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

foreach z in H M L{
xi: reg ln_RT_it_TECH ScRC3_r ln_SIZE priceRC3 if CLS2018=="`z'", robust
quietly outreg2 using "TABLE_B3.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

//Table B.4 (eq.4 and eq.5)//
**Exploring the relationship between dependence on FORESTRY resources and diversification of overall, non-resource and technologically advanced exports**
xi: ivreg2 ln_RT ScRC2_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC2, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons  excel replace 
xi: ivreg2 ln_RT ScRC2_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC2, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 ln_RT ScRC2_r INST_ip interaction_INST_RC2 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC2, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen

foreach z in ln_RT_inr_RC2 ln_RT_it_TECH{
xi: ivreg2 `z' ScRC2_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC2, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC2_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC2, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC2_r INST_ip interaction_INST_RC2 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC2, gmm2s robust
quietly outreg2 using "TABLE_B4.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

//Table B.5 (eq.4 and eq.5)//
**Exploring the relationship between dependence on FUEL resources and diversification of overall, non-resource and technologically advanced exports**
xi: ivreg2 ln_RT ScRC3_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC3, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons  excel replace 
xi: ivreg2 ln_RT ScRC3_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC3, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 ln_RT ScRC3_r INST_ip interaction_INST_RC3 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC3, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen

foreach z in ln_RT_inr_RC3 ln_RT_it_TECH{
xi: ivreg2 `z' ScRC3_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC3, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC3_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC3, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC3_r INST_ip interaction_INST_RC3 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC3, gmm2s robust
quietly outreg2 using "TABLE_B5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

//Table B.6 (eq.4 and eq.5)//
**Exploring the relationship between dependence on METAL resources and diversification of overall, non-resource and technologically advanced exports**
xi: ivreg2 ln_RT ScRC4_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC4, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons  excel replace 
xi: ivreg2 ln_RT ScRC4_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC4, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 ln_RT ScRC4_r INST_ip interaction_INST_RC4 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC4, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen

foreach z in ln_RT_inr_RC4 ln_RT_it_TECH{
xi: ivreg2 `z' ScRC4_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC4, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC4_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC4, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC4_r INST_ip interaction_INST_RC4 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC4, gmm2s robust
quietly outreg2 using "TABLE_B6.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

//Table B.7 (eq.4 and eq.5)//
**Exploring the relationship between dependence on MINERAL resources and diversification of overall, non-resource and technologically advanced exports**
xi: ivreg2 ln_RT ScRC5_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC5, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons  excel replace 
xi: ivreg2 ln_RT ScRC5_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC5, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 ln_RT ScRC5_r INST_ip interaction_INST_RC5 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC5, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen

foreach z in ln_RT_inr_RC5 ln_RT_it_TECH{
xi: ivreg2 `z' ScRC5_r ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC5, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC5_r INST_ip ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC5, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
xi: ivreg2 `z' ScRC5_r INST_ip interaction_INST_RC5 ln_SIZE (l.ln_DEV=l2.ln_DEV) priceRC5, gmm2s robust
quietly outreg2 using "TABLE_B7.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons excel appen
}

//Table B.8 (eq.4 with DEV^2)//
**Relationship between export diversification and resource dependence (all types of resources)**
xi: ivreg2 ln_RT ln_SIZE ScRC1_r (lag lagsq  = l.lag l.lagsq) priceRC1, gmm2s robust
wherext lag lagsq
quietly outreg2 using "TABLE_B8.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons addstat("Turning point [100k US$]", `r(argext)') excel replace 

foreach k in RC2 RC3 RC4 RC5{
xi: ivreg2 ln_RT ln_SIZE Sc`k'_r (lag lagsq  = l.lag l.lagsq) price`k', gmm2s robust
wherext lag lagsq
quietly outreg2 using "TABLE_B8.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons addstat("Turning point [100k US$]", `r(argext)') excel appen
}

foreach k in RC1 RC2 RC3 RC4 RC5{
xi: ivreg2 ln_RT_inr_`k' ln_SIZE Sc`k'_r (lag lagsq  = l.lag l.lagsq) price`k', gmm2s robust
wherext lag lagsq
quietly outreg2 using "TABLE_B8.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons addstat("Turning point [100k US$]", `r(argext)') excel appen
}

foreach k in RC1 RC2 RC3 RC4 RC5{
xi: ivreg2 ln_RT_it_TECH ln_SIZE Sc`k'_r (lag lagsq  = l.lag l.lagsq) price`k', gmm2s robust
wherext lag lagsq
quietly outreg2 using "TABLE_B8.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nor2 nocons addstat("Turning point [100k US$]", `r(argext)') excel appen
}
