**********************
*PLEASE CITE PAPER AS:
*Zarach, Z.H., Parteka A. (2023). Export diversification and dependence on natural resources. Economic Modelling Volume 126, September 2023, 106436. https://doi.org/10.1016/j.econmod.2023.106436
***********************************************
*IF YOU USE REPLICATION PACKAGE, PLEASE CITE AS:
*Zarach, Z.H., & Parteka, A. (2023). Data accompanying the paper: Zarach and Parteka (2023), Export diversification and dependence on natural resources, Economic Modelling (Elsevier), 126 (2023) 106436. [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/844p-8614

************************************************************************************************************************
*THIS DO.FILE CREATES SELECTED FIGURES
*Figure 5 (based on values included in Table A.7 and Table A.8) and Figure B.2 were created by the use of Excel software 
************************************************************************************************************************
clear all
set more off
cd "D:\NR_DECOMPOSITION"
**********
*MAIN TEXT
**********

//Figure 1//
**Part A**
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

*Value of resource exports expressed in billion US$
replace EcRC1_r = EcRC1_r/1000000
collapse(sum) EcRC1_r, by (CLS2018 year)
 
twoway (line EcRC1_r year if CLS2018=="H" , lcolor(black) lwidth(medthick) lpattern(longdash_dot)) (line EcRC1_r year if CLS2018=="M", lcolor(black) lwidth(medthick) lpattern(solid)) (line EcRC1_r year if CLS2018=="L", lcolor(black) lwidth(medthick) lpattern(shortdash)) , title("(A)") ytitle("[billion USD]") xtitle("year") xlabel(1996(4)2020) legend(rows(3) position(6) order(1 "high income countries" 2 "middle income countries"  3 "low income countries" ) region(lpattern(blank))) graphregion(fcolor(white)) scheme(s2mono)

**Part B**
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

lowess EwRC2 year, generate (fit_RC2)
lowess EwRC3 year, generate (fit_RC3)
lowess EwRC4 year, generate (fit_RC4)
lowess EwRC5 year, generate (fit_RC5)

collapse fit_RC2 fit_RC3 fit_RC4 fit_RC5, by(year)

gen zero=0
gen S_FORESTRY=fit_RC2/(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)*100
gen S_FUEL=(fit_RC2 + fit_RC3)/(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)*100
gen S_METAL=(fit_RC2 + fit_RC3 + fit_RC4)/(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)*100
gen S_MINERAL=(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)/(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)*100
graph drop _all

twoway (rarea zero S_FORESTRY year, color(black) lpattern (solid) lwidth(medium)) (rarea S_FORESTRY S_FUEL year, lpattern (solid) lcolor (gs4) color(gs4) lwidth(medium)) (rarea S_FUEL S_METAL year, lpattern (solid) lcolor (gs10) color(gs10) lwidth(medium)) (rarea S_METAL S_MINERAL year, lpattern (solid) lcolor (gs13) color(gs13) lwidth(medium)), title("(B)") xtitle("year") ytitle("share in total NR exports [%]", size(medsmall) margin(medium)) xlabel(1996(2)2018) ylabel(0(20)100)  legend(row(1) order(1 "FORESTRY" 2 "FUEL" 3 "METAL" 4 "MINERAL") size(medium) region(lpattern(blank))) graphregion(color(white)) scheme(s2mono) 

//Figure 2//
**Part A**
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear
twoway (scatter share_RC1 DEV, sort mcolor(gs8) msize(tiny) msymbol(circle_hollow)) (lowess share_RC1 DEV, bwidth(0.5) lcolor(black) lwidth(medthick) lpattern(solid)), title("(A)") ytitle("share of NR in total exports [%]") xtitle("output per worker (2017 PPP US$)") xlabel(0(50000)250000) ylabel(0(20)100) legend(rows(2) position(6) order(1 "country-year obs." 2 "lowess, all sample (160)") region(lpattern(blank))) graphregion(color(white)) scheme(s2mono)

**Part B**
*Calculating share of various resource types in overall NR group 
foreach i in RC2 RC3 RC4 RC5{
gen sh_`i'=(Ec`i'_r/EcRC1_r)*100
}

lowess sh_RC2 DEV, generate (fit_RC2)
lowess sh_RC3 DEV, generate (fit_RC3)
lowess sh_RC4 DEV, generate (fit_RC4)
lowess sh_RC5 DEV, generate (fit_RC5)

collapse fit_RC2 fit_RC3 fit_RC4 fit_RC5, by(DEV)

gen zero=0
gen S_FORESTRY=fit_RC2/(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)*100
gen S_FUEL=(fit_RC2 + fit_RC3)/(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)*100
gen S_METAL=(fit_RC2 + fit_RC3 + fit_RC4)/(fit_RC2 + fit_RC3 + fit_RC4 + fit_RC5)*100
gen S_MINERAL=100
graph drop _all

*Dropping negative observations which affect the graph
drop in 3666/3680

twoway (rarea zero S_FORESTRY DEV, color(black) lpattern (solid) lwidth(medium)) (rarea S_FORESTRY S_FUEL DEV, lpattern (solid) lcolor (gs4) color(gs4) lwidth(medium)) (rarea S_FUEL S_METAL DEV, lpattern (solid) lcolor (gs10) color(gs10) lwidth(medium)) (rarea S_METAL S_MINERAL DEV, lpattern (solid) lcolor (gs13) color(gs13) lwidth(medium)), title("(B)") xtitle("output per worker (2017 PPP US$)") ytitle("share in total NR exports [%]", size(medsmall) margin(medium)) xlabel(0(40000)200000) ylabel(0(20)100)  legend(row(1) order(1 "FORESTRY" 2 "FUEL" 3 "METAL" 4 "MINERAL") size(medium) region(lpattern(blank))) graphregion(color(white)) scheme(s2mono) 

//Figure 3//
graph drop _all
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

foreach k in Egypt Iran Latvia Oman{
line share_RC1 share_TECH year if CountryName=="`k'", legend(order(1 "all NR" 2 "TECH")) title("`k'") xtitle("year") xlabel(1996(2)2018) ytitle("share in total exports (in %)") ylabel(0(20)100) graphregion(color(white)) lpattern(solid longdash) lcolor(black black) name(`k')
}
line share_RC1 share_TECH year if CountryName=="Saudi Arabia", legend(order(1 "all NR" 2 "TECH")) title("Saudi Arabia") xtitle("year") xlabel(1996(2)2018) ytitle("share in total exports (in %)") ylabel(0(20)100) graphregion(color(white)) lpattern(solid longdash) lcolor(black black) name(SaudiArabia) 
line share_RC1 share_TECH year if CountryName=="United Arab Emirates", legend(order(1 "all NR" 2 "TECH")) title("United Arab Emirates") xtitle("year") xlabel(1996(2)2018) ytitle("share in total exports (in %)") ylabel(0(20)100) graphregion(color(white)) lpattern(solid longdash) lcolor(black black) name(UnitedArabEmirates) 

graph combine Egypt Iran Latvia Oman SaudiArabia UnitedArabEmirates, iscale(0.4) rows(3) cols(2) ysize(20) xsize(18) graphregion(color(white))

//Figure 4//
**********************************************
**Part A (products split into NR and non-NR)**
graph drop _all
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

//GRAPH (1)//
twoway (lowess RT DEV, lcolor(black) lwidth(medthick) lpattern(solid)) (lowess withinRC1_r DEV , lcolor(red) lwidth(medthick) lpattern(solid)) (lowess withinRC1_nr DEV , lcolor(black) lwidth(medthick) lpattern(longdash)) (lowess betweenRC1 DEV, lcolor(gray) lwidth(medthick) lpattern(solid)), legend(order(1 "relative/weighted Theil (RT)" 2 "within resource component" 3 "within non-resource component" 4 "between component") region(lcolor(white))) xlabel(0(50000)300000) title("(1)") xtitle("output per worker(2017 PPP US$)") ytitle("index value") graphregion(color(white)) scheme(s2mono)
//GRAPH (2)//
lowess withinRC1_r DEV, generate (fit_withinRC1_r)
lowess withinRC1_nr DEV, generate (fit_withinRC1_nr)
lowess betweenRC1 DEV, generate (fit_betweenRC1)

collapse fit_betweenRC1 fit_withinRC1_nr fit_withinRC1_r, by(DEV)

gen zero=0
gen S_between=fit_betweenRC1/(fit_withinRC1_r+fit_withinRC1_nr+fit_betweenRC1)*100
gen S_within_r=(fit_betweenRC1+fit_withinRC1_r)/(fit_withinRC1_r+fit_withinRC1_nr+fit_betweenRC1)*100
gen S_within_nr=100
graph drop _all

twoway (rarea zero S_between DEV, color(gray) lpattern (solid) lwidth(medium)) (rarea S_between S_within_r DEV, color(red) lwidth(medium)) (rarea S_within_r S_within_nr DEV, lpattern (dash) lcolor (black) color(gs14) lwidth(medium)), xlabel(0(50000)300000) xtitle("output per worker(2017 PPP US$)")  ytitle("share of RT (in %)", size(medium) alignment(top) margin(medsmall)) title("(2)") legend(row(1) order(1 "between" 2 "within res" 3 "within non-res" ) size(medium) region(lpattern(blank))) graphregion(color(white)) scheme(s2mono)

**************************************************
**Part B (products split into FUEL and non-FUEL)**
graph drop _all
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

//GRAPH (1)//
twoway (lowess RT DEV, lcolor(black) lwidth(medthick) lpattern(solid)) (lowess withinRC3_r DEV, lcolor(red) lwidth(medthick) lpattern(solid)) (lowess withinRC3_nr DEV, lcolor(black) lwidth(medthick) lpattern(longdash)) (lowess betweenRC3 DEV, lcolor(gray) lwidth(medthick) lpattern(solid)), legend(order(1 "relative/weighted Theil (RT)" 2 "within fuel component" 3 "within non-fuel component" 4 "between component") region(lcolor(white))) xlabel(0(50000)300000) title("(1)") xtitle("output per worker(2017 PPP US$)") ytitle("index value") graphregion(color(white)) scheme(s2mono)

//GRAPH (2)//
lowess withinRC3_r DEV, generate (fit_withinRC3_r)
lowess withinRC3_nr DEV, generate (fit_withinRC3_nr)
lowess betweenRC3 DEV, generate (fit_betweenRC3)

collapse fit_betweenRC3 fit_withinRC3_nr fit_withinRC3_r, by(DEV)

gen zero=0
gen S_between=fit_betweenRC3/(fit_withinRC3_r+fit_withinRC3_nr+fit_betweenRC3)*100
gen S_within_r=(fit_betweenRC3+fit_withinRC3_r)/(fit_withinRC3_r+fit_withinRC3_nr+fit_betweenRC3)*100
gen S_within_nr=100
graph drop _all

twoway (rarea zero S_between DEV, color(gray) lpattern (solid) lwidth(medium)) (rarea S_between S_within_r DEV, color(red) lwidth(medium)) (rarea S_within_r S_within_nr DEV, lpattern (dash) lcolor (black) color(gs14) lwidth(medium)), xlabel(0(50000)300000) xtitle("output per worker(2017 PPP US$)") ytitle("share of RT (in %)", size(medium) alignment(top) margin(medsmall)) title("(2)") legend(row(1) order(1 "between" 2 "within fuel" 3 "within non-fuel" ) size(medium) region(lpattern(blank))) graphregion(color(white)) scheme(s2mono)

//Figure 6//
**Margin plots computed for estimations of eq.(5) interacting the resources’ share in total exports (ALL NR) and the quality of institutions**
**Global threshold values for natural resource share (veryhigh, high, medium, low, very low) roughly based on variable’s percentiles (10th, 25th, 50th, 75th and 90th)**

//Estimation with ln_RT_inr_RC1//
graph drop _all
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 
xtset countryid year

eststo clear
eststo: xi: reg ln_RT_inr_RC1 c.share_RC1##c.INST_ip ln_SIZE l.ln_DEV priceRC1, robust

global veryhigh = 90
global high = 60
global medium = 30
global low = 15
global verylow = 5  

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC1=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC1=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("(1)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT non-resource)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=5%" 2 "NR share=15%" 3 "NR share=30%" 4 "NR share=60%" 5 "NR share=90%") size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTnonres) 

//Estimation with ln_RT_it_TECH//
eststo clear
eststo: xi: reg ln_RT_it_TECH c.share_RC1##c.INST_ip ln_SIZE l.ln_DEV priceRC1, robust

global veryhigh = 90
global high = 60
global medium = 30
global low = 15
global verylow = 5  

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC1=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC1=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("(2)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT tech-exports)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=5%" 2 "NR share=15%" 3 "NR share=30%" 4 "NR share=60%" 5 "NR share=90%") size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTtech) 

graph combine RTnonres RTtech, iscale(0.7) ysize(9) xsize(20) graphregion(color(white))

***********
*APPENDIX B
***********

//Figure B.1//
graph drop _all
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

*Value of resource exports expressed in billion US$
foreach z in EcRC2_r EcRC3_r EcRC4_r EcRC5_r{
replace `z'=`z' / 1000000
}
collapse(sum) EcRC*, by (CLS2018 year)

twoway (line EcRC2_r year if CLS2018=="H" , lcolor(black) lwidth(medthick) lpattern(longdash_dot)) (line EcRC2_r year if CLS2018=="M", lcolor(black) lwidth(medthick) lpattern(solid)) (line EcRC2_r year if CLS2018=="L", lcolor(black) lwidth(medthick) lpattern(shortdash)) , title("FORESTRY") ytitle("[billion USD]") xtitle("year") xlabel(1996(4)2020) legend(rows(3) position(6) order(1 "high income countries" 2 "middle income countries"  3 "low income countries" ) region(lpattern(blank))) graphregion(fcolor(white)) scheme(s2mono) name(RC2) 
twoway (line EcRC3_r year if CLS2018=="H" , lcolor(black) lwidth(medthick) lpattern(longdash_dot)) (line EcRC3_r year if CLS2018=="M", lcolor(black) lwidth(medthick) lpattern(solid)) (line EcRC3_r year if CLS2018=="L", lcolor(black) lwidth(medthick) lpattern(shortdash)) , title("FUEL") ytitle("[billion USD]") xtitle("year") xlabel(1996(4)2020) legend(rows(3) position(6) order(1 "high income countries" 2 "middle income countries"  3 "low income countries" ) region(lpattern(blank))) graphregion(fcolor(white)) scheme(s2mono) name(RC3)
twoway (line EcRC4_r year if CLS2018=="H" , lcolor(black) lwidth(medthick) lpattern(longdash_dot)) (line EcRC4_r year if CLS2018=="M", lcolor(black) lwidth(medthick) lpattern(solid)) (line EcRC4_r year if CLS2018=="L", lcolor(black) lwidth(medthick) lpattern(shortdash)) , title("METAL") ytitle("[billion USD]") xtitle("year") xlabel(1996(4)2020) legend(rows(3) position(6) order(1 "high income countries" 2 "middle income countries"  3 "low income countries" ) region(lpattern(blank))) graphregion(fcolor(white)) scheme(s2mono) name(RC4)
twoway (line EcRC5_r year if CLS2018=="H" , lcolor(black) lwidth(medthick) lpattern(longdash_dot)) (line EcRC5_r year if CLS2018=="M", lcolor(black) lwidth(medthick) lpattern(solid)) (line EcRC5_r year if CLS2018=="L", lcolor(black) lwidth(medthick) lpattern(shortdash)) , title("MINERAL") ytitle("[billion USD]") xtitle("year") xlabel(1996(4)2020) legend(rows(3) position(6) order(1 "high income countries" 2 "middle income countries"  3 "low income countries" ) region(lpattern(blank))) graphregion(fcolor(white)) scheme(s2mono) name(RC5)

graph combine RC2 RC3 RC4 RC5, iscale(0.5) ysize(17) xsize(17) graphregion(color(white))

//Figure B.9//
**Margin plots computed for estimations of eq.(5) interacting the resources’ share in total exports (A.FORESTRY, B.FUEL, C.METAL, D.MINERAL) and the quality of institutions**
**Global threshold values for natural resource share (veryhigh, high, medium, low, very low) roughly based on variable’s percentiles (10th, 25th, 50th, 75th and 90th)**
graph drop _all
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 
xtset countryid year

***********
*A.FORESTRY
***********
//Estimation with ln_RT_inr_RC2//
eststo clear
eststo: xi: reg ln_RT_inr_RC2 c.share_RC2##c.INST_ip ln_SIZE l.ln_DEV priceRC2, robust

global veryhigh = 10
global high = 5
global medium = 2
global low = 1
global verylow = 0.5  

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC2=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC2=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("A.FORESTRY", position(11) size(medium)) subtitle("(1)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT non-resource)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=0.5%" 2 "NR share=1%" 3 "NR share=2%" 4 "NR share=5%" 5 "NR share=10%") size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTnonresRC2)

//Estimation with ln_RT_it_TECH//
eststo clear
eststo: xi: reg ln_RT_it_TECH c.share_RC2##c.INST_ip ln_SIZE l.ln_DEV priceRC2, robust

global veryhigh = 10
global high = 5
global medium = 2
global low = 1
global verylow = 0.5  

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC2=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC2=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("  ") subtitle("(2)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT tech-exports)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=0.5%" 2 "NR share=1%" 3 "NR share=2%" 4 "NR share=5%" 5 "NR share=10%") size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTtechRC2)

graph combine RTnonresRC2 RTtechRC2, iscale(0.7) ysize(9) xsize(20) graphregion(color(white))

*******
*B.FUEL
*******
//Estimation with ln_RT_inr_RC3//
eststo clear
eststo: xi: reg ln_RT_inr_RC3 c.share_RC3##c.INST_ip ln_SIZE l.ln_DEV priceRC3, robust

global veryhigh = 80
global high = 50
global medium = 20
global low = 10
global verylow = 2   

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC3=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC3=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("B.FUEL", position(11) size(medium)) subtitle("(1)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT non-resource)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=2%" 2 "NR share=10%" 3 "NR share=20%" 4 "NR share=30%" 5 "NR share=80%")  size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTnonresRC3)

//Estimation with ln_RT_it_TECH//
eststo clear
eststo: xi: reg ln_RT_it_TECH c.share_RC3##c.INST_ip ln_SIZE l.ln_DEV priceRC3, robust

global veryhigh = 80
global high = 50
global medium = 20
global low = 10
global verylow = 2  

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC3=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC3=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("  ") subtitle("(2)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT tech-exports)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=2%" 2 "NR share=10%" 3 "NR share=20%" 4 "NR share=30%" 5 "NR share=80%")  size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTtechRC3)

graph combine RTnonresRC3 RTtechRC3, iscale(0.7) ysize(9) xsize(20) graphregion(color(white))

********
*C.METAL
********
//Estimation with ln_RT_inr_RC4//
eststo clear
eststo: xi: reg ln_RT_inr_RC4 c.share_RC4##c.INST_ip ln_SIZE l.ln_DEV priceRC4, robust

global veryhigh = 20
global high = 12
global medium = 5
global low = 2
global verylow = 1  

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC4=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC4=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("C.METAL", position(11) size(medium)) subtitle("(1)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT non-resource)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=1%" 2 "NR share=2%" 3 "NR share=5%" 4 "NR share=12%" 5 "NR share=20%")  size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTnonresRC4)

//Estimation with ln_RT_it_TECH//
eststo clear
eststo: xi: reg ln_RT_it_TECH c.share_RC4##c.INST_ip ln_SIZE l.ln_DEV priceRC4, robust

global veryhigh = 20
global high = 12
global medium = 5
global low = 2
global verylow = 1 

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC4=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC4=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("  ") subtitle("(2)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT tech-exports)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=1%" 2 "NR share=2%" 3 "NR share=5%" 4 "NR share=12%" 5 "NR share=20%")  size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTtechRC4)

graph combine RTnonresRC4 RTtechRC4, iscale(0.7) ysize(9) xsize(20) graphregion(color(white))

**********
*D.MINERAL
**********
//Estimation with ln_RT_inr_RC5//
eststo clear
eststo: xi: reg ln_RT_inr_RC5 c.share_RC5##c.INST_ip ln_SIZE l.ln_DEV priceRC5, robust

global veryhigh = 20
global high = 12
global medium = 5
global low = 2
global verylow = 1  

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC5=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC5=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("D.MINERAL", position(11) size(medium)) subtitle("(1)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT non-resource)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=1%" 2 "NR share=2%" 3 "NR share=5%" 4 "NR share=12%" 5 "NR share=20%")  size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTnonresRC5)

//Estimation with ln_RT_it_TECH//
eststo clear
eststo: xi: reg ln_RT_it_TECH c.share_RC5##c.INST_ip ln_SIZE l.ln_DEV priceRC5, robust

global veryhigh = 20
global high = 12
global medium = 5
global low = 2
global verylow = 1 

display $veryhigh
display $high
display $medium
display $low
display $verylow

margins, dydx(INST_ip) at (share_RC5=($veryhigh $high $medium $low $verylow))
margins, at(INST_ip=(0(20)100) share_RC5=($veryhigh $high $medium $low $verylow))
marginsplot, recast(line) noci title("  ") subtitle("(2)") xtitle("quality of institutions (percentile rank)") ytitle ("linear prediction (RT tech-exports)", size(medium) alignment(top) margin(medsmall)) plot1opts(lcolor(black)) plot2opts(lcolor(black) lpattern(dash)) plot3opts(lcolor(red)) plot4opts(lcolor(red) lpattern(dash)) plot5opts(lcolor(gs10)) legend(order(1 "NR share=1%" 2 "NR share=2%" 3 "NR share=5%" 4 "NR share=12%" 5 "NR share=20%")  size(medsmall) rows(2) region(lpattern(blank))) graphregion(color(white)) scheme(s2color) name(RTtechRC5)

graph combine RTnonresRC5 RTtechRC5, iscale(0.7) ysize(9) xsize(20) graphregion(color(white))
