**********************
*PLEASE CITE PAPER AS:
*Zarach, Z.H., Parteka A. (2023). Export diversification and dependence on natural resources. Economic Modelling Volume 126, September 2023, 106436. https://doi.org/10.1016/j.econmod.2023.106436
***********************************************
*IF YOU USE REPLICATION PACKAGE, PLEASE CITE AS:
*Zarach, Z.H., & Parteka, A. (2023). Data accompanying the paper: Zarach and Parteka (2023), Export diversification and dependence on natural resources, Economic Modelling (Elsevier), 126 (2023) 106436. [Data set]. Gdańsk University of Technology. https://doi.org/10.34808/844p-8614

*****************************************************************
*THIS DO.FILE CREATES SELECTED TABLES WITH DESCRIPTIVE STATISTICS
*****************************************************************
clear all
set more off
cd "D:\NR_DECOMPOSITION"
**********
*MAIN TEXT
**********

//Table 1//
**Values presented in Table 1 have been round up
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear
keep if year==2018

foreach k in RC1 RC2 RC3 RC4 RC5{
mean RCAspecres`k' if CLS2018=="H"
mean RCAspecres`k' if CLS2018=="M"
mean RCAspecres`k' if CLS2018=="L"
}
*For the sake of calculating share of product codes with RCA>1 in total number of resource products, below are given the numbers of product codes in all resource classifications:
*nRC1=320
*nRC2=47
*nRC3=39
*nRC4=118
*nRC5=116

//Table 2//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

//FULL SAMPLE
mean RT withinRC1_nr withinRC1_r betweenRC1
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1
//<50k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV <= 50000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV <= 50000
//50-100k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 50000 & DEV <= 100000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 50000 & DEV <= 100000
//100-150k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 100000 & DEV <= 150000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 100000 & DEV <= 150000
//150-200k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 150000 & DEV <= 200000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 150000 & DEV <= 200000
//200-250k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 200000 & DEV <= 250000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 200000 & DEV <= 250000
//>250k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 250000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 250000

//Table 3//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

//ALL NR (RC1 classification)
mean RT withinRC1_nr withinRC1_r betweenRC1
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1
//FORESTRY (RC2 classification)
mean RT withinRC2_nr withinRC2_r betweenRC2
mean share_RT share_withinRC2_nr share_withinRC2_r share_betweenRC2
//FUEL (RC3 classification)
mean RT withinRC3_nr withinRC3_r betweenRC3
mean share_RT share_withinRC3_nr share_withinRC3_r share_betweenRC3
//METAL (RC4 classification)
mean RT withinRC4_nr withinRC4_r betweenRC4
mean share_RT share_withinRC4_nr share_withinRC4_r share_betweenRC4
//MINERAL (RC5 classification)
mean RT withinRC5_nr withinRC5_r betweenRC5
mean share_RT share_withinRC5_nr share_withinRC5_r share_betweenRC5

//Table 4//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 
keep if NR_exporter==1

//FULL SAMPLE
mean RT withinRC1_nr withinRC1_r betweenRC1
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1
//<50k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV <= 50000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV <= 50000
//50-100k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 50000 & DEV <= 100000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 50000 & DEV <= 100000
//100-150k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 100000 & DEV <= 150000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 100000 & DEV <= 150000
//150-200k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 150000 & DEV <= 200000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 150000 & DEV <= 200000
//200-250k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 200000 & DEV <= 250000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 200000 & DEV <= 250000
//>250k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 250000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 250000

***********
*APPENDIX A
***********
//Table A.1//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

tab CountryName if CLS2018=="H"
tab CountryName if CLS2018=="M"
tab CountryName if CLS2018=="L"

//Table A.2//
tab CountryName if CLS2018=="H" & NR_exporter==1
tab CountryName if CLS2018=="M" & NR_exporter==1
tab CountryName if CLS2018=="L" & NR_exporter==1

//Table A.5//
*Creating logarithms of decomposition components (RC1 classification - ALL NR)
foreach z in betweenRC1 withinRC1_r withinRC1_nr{
replace `z'=0.0000000001 if `z'==.|`z'==0| `z'<0
gen ln_`z' = ln(`z')
}

xtset countryid year

xi: reg ln_RT ln_DEV i.year i.Exporter, robust
quietly outreg2 using "TABLE_A5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nocons excel replace

foreach z in withinRC1_r withinRC1_nr betweenRC1 {
xi: reg ln_`z' ln_DEV i.year i.Exporter, robust
quietly outreg2 using "TABLE_A5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nocons excel appen 
}

foreach z in RT withinRC1_r withinRC1_nr betweenRC1{
xi: ivreg2 ln_`z' (ln_DEV=l.ln_DEV) i.year i.Exporter, gmm2s robust
quietly outreg2 using "TABLE_A5.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) nocons excel appen 
}

//Table A.6//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 
keep if NR_exporter!=1

//FULL SAMPLE
mean RT withinRC1_nr withinRC1_r betweenRC1
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1
//<50k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV <= 50000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV <= 50000
//50-100k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 50000 & DEV <= 100000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 50000 & DEV <= 100000
//100-150k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 100000 & DEV <= 150000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 100000 & DEV <= 150000
//150-200k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 150000 & DEV <= 200000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 150000 & DEV <= 200000
//200-250k
mean RT withinRC1_nr withinRC1_r betweenRC1 if DEV > 200000 & DEV <= 250000
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if DEV > 200000 & DEV <= 250000

//Table A.7//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

foreach i in ARE IRQ TCD ISL JAM LVA{
mean RT withinRC1_nr withinRC1_r betweenRC1 if Exporter=="`i'" & year==1996
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if Exporter=="`i'" & year==1996

mean RT withinRC1_nr withinRC1_r betweenRC1 if Exporter=="`i'" & year==2018
mean share_RT share_withinRC1_nr share_withinRC1_r share_betweenRC1 if Exporter=="`i'" & year==2018
}

//Table A.8//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear 

gen shareRC1_nr = 100 - share_RC1
foreach i in ARE IRQ TCD ISL JAM LVA{
mean share_RC1 shareRC1_nr if Exporter=="`i'" & year==1996
mean share_RC1 shareRC1_nr if Exporter=="`i'" & year==2018
}

//Table A.9//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear
xtset countryid year

xi: reg share_RC1 l.share_RC1 priceRC1, robust
quietly outreg2 using "TABLE_A9.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) excel replace

foreach k in RC2 RC3 RC4 RC5{
xi: reg share_`k' l.share_`k' price`k', robust
quietly outreg2 using "TABLE_A9.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) excel appen 
}

//Table A.10//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear
xtset countryid year

xi: reg ln_RT l.ln_DEV, robust
quietly outreg2 using "TABLE_A10.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) excel replace

xi: reg ln_RT l.ln_DEV i.year, robust
quietly outreg2 using "TABLE_A10.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) excel appen 

xi: reg ln_RT l.ln_DEV i.Exporter, robust
quietly outreg2 using "TABLE_A10.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) excel appen 

xi: reg ln_RT l.ln_DEV i.year i.Exporter, robust
quietly outreg2 using "TABLE_A10.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) excel appen 

//Table A.11//
use "DATA\EconomicModelling_ZarachParteka_FinalData.dta", clear
xtset countryid year

xi: reg ln_RT lag lagsq, robust
wherext lag lagsq
quietly outreg2 using "TABLE_A11.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) addstat("Turning point [100k US$]", `r(argext)') excel replace

eststo: xi: reg ln_RT lag lagsq i.year, robust
wherext lag lagsq
quietly outreg2 using "TABLE_A11.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) addstat("Turning point [100k US$]", `r(argext)') excel appen 

eststo: xi: reg ln_RT lag lagsq i.Exporter, robust
wherext lag lagsq
quietly outreg2 using "TABLE_A11.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) addstat("Turning point [100k US$]", `r(argext)') excel appen 

eststo: xi: reg ln_RT lag lagsq i.year i.Exporter, robust
wherext lag lagsq
quietly outreg2 using "TABLE_A11.xls", symbol(***, **, *) alpha(0.01, 0.05, 0.10) dec(3) drop(_I* o._I*) addstat("Turning point [100k US$]", `r(argext)') excel appen 


